@@ -22,10 +22,11 @@ like saying they are optional (but expected), and TRAILING=None is
 like saying they are required.  You can't (afaik) do TRAILING=None
 with *args.
 
-See lamson.args for more details.
+See python-modargs for more details.
 """
 
-from lamson import server, args, utils, mail, routing, queue, encoding
+from lamson import server, utils, mail, routing, queue, encoding
+from modargs import args
 from pkg_resources import resource_stream
 from zipfile import ZipFile
 import glob
@@ -39,7 +40,7 @@ import email
 
 def log_command(port=8825, host='127.0.0.1', chroot=False,
                 chdir=".", uid=False, gid=False, umask=False, pid="./run/log.pid",
-               FORCE=False):
+               FORCE=False, debug=False):
     """
     Runs a logging only server on the given hosts and port.  It logs
     each message it receives and also stores it to the run/queue 
@@ -59,7 +60,7 @@ def log_command(port=8825, host='127.0.0.1', chroot=False,
     uid or gid without doing the priv drop operation.
     """
     loader = lambda: utils.make_fake_settings(host, port)
-    utils.start_server(pid, FORCE, chroot, chdir, uid, gid, umask, loader)
+    utils.start_server(pid, FORCE, chroot, chdir, uid, gid, umask, loader, debug)
 
 
 def send_command(port=8825, host='127.0.0.1', username=False, password=False,
@@ -103,14 +104,14 @@ def sendmail_command(port=8825, host='127.0.0.1', debug=0, TRAILING=None):
     relay = server.Relay(host, port=port,
                            debug=debug)
     data = sys.stdin.read()
-    msg = mail.MailRequest(None, TRAILING, None, data)
-    relay.deliver(msg)
+    msg = mail.MailRequest(Peer=None, From=None, To=None, Data=data)
+    relay.deliver(msg, To=TRAILING)
 
 
 
 
 def start_command(pid='./run/smtp.pid', FORCE=False, chroot=False, chdir=".",
-                  boot="config.boot", uid=False, gid=False, umask=False):
+                  boot="config.boot", uid=False, gid=False, umask=False, debug=False):
     """
     Runs a lamson server out of the current directory:
 
@@ -118,7 +119,7 @@ def start_command(pid='./run/smtp.pid', FORCE=False, chroot=False, chdir=".",
             -umask False -uid False -gid False -boot config.boot
     """
     loader = lambda: utils.import_settings(True, from_dir=os.getcwd(), boot_module=boot)
-    utils.start_server(pid, FORCE, chroot, chdir, uid, gid, umask, loader)
+    utils.start_server(pid, FORCE, chroot, chdir, uid, gid, umask, loader, debug)
 
 
 def stop_command(pid='./run/smtp.pid', KILL=False, ALL=False):
