@@ -87,6 +87,8 @@ ENCODING_REGEX = re.compile(r"\=\?([a-z0-9\-]+?)\?([bq])\?", REGEX_OPTS)
 ENCODING_END_REGEX = re.compile(r"\?=", REGEX_OPTS)
 INDENT_REGEX = re.compile(r"\n\s+")
 
+VALUE_IS_EMAIL_ADDRESS = lambda v: '@' in v
+ADDRESS_HEADERS_WHITELIST = ['From', 'To', 'Delivered-To', 'Cc', 'Bcc']
 
 class EncodingError(Exception): 
     """Thrown when there is an encoding error."""
@@ -124,6 +126,9 @@ class MailBase(object):
     def __delitem__(self, key):
         del self.headers[normalize_header(key)]
 
+    def __nonzero__(self):
+        return self.body != None or len(self.headers) > 0 or len(self.parts) > 0
+
     def keys(self):
         """Returns the sorted keys."""
         return sorted(self.headers.keys())
@@ -134,6 +139,7 @@ class MailBase(object):
         indicates the file name.
         """
         assert filename, "You can't attach a file without a filename."
+        assert ctype.lower() == ctype, "Hey, don't be an ass.  Use a lowercase content type."
 
         part = MailBase()
         part.body = data
@@ -148,11 +154,18 @@ class MailBase(object):
         This attaches a simpler text encoded part, which doesn't have a
         filename.
         """
+        assert ctype.lower() == ctype, "Hey, don't be an ass.  Use a lowercase content type."
+
         part = MailBase()
         part.body = data
         part.content_encoding['Content-Type'] = (ctype, {})
         self.parts.append(part)
 
+    def walk(self):
+        for p in self.parts:
+            yield p
+            for x in p.walk():
+                yield x
 
 
 class MIMEPart(MIMEBase):
@@ -162,8 +175,8 @@ class MIMEPart(MIMEBase):
     thing you'd encode, there's just this one, and it figures out how to
     encode what you ask it.
     """
-    def __init__(self, type, **params):
-        self.maintype, self.subtype = type.split('/')
+    def __init__(self, type_, **params):
+        self.maintype, self.subtype = type_.split('/')
         MIMEBase.__init__(self, self.maintype, self.subtype, **params)
 
     def add_text(self, content):
@@ -211,8 +224,9 @@ def from_message(message):
 
     # parse the content information out of message
     for k in CONTENT_ENCODING_KEYS:
-        params = parse_parameter_header(message, k)
-        mail.content_encoding[k] = params
+        setting, params = parse_parameter_header(message, k)
+        setting = setting.lower() if setting else setting
+        mail.content_encoding[k] = (setting, params)
 
     # copy over any keys that are not part of the content information
     for k in message.keys():
@@ -245,19 +259,22 @@ def to_message(mail):
             ctype = 'text/plain'
     else:
         if mail.parts:
-            assert ctype.startswith("multipart"), "Content type should be multipart, not %r" % ctype
+            assert ctype.startswith("multipart") or ctype.startswith("message"), "Content type should be multipart or message, not %r" % ctype
 
     # adjust the content type according to what it should be now
     mail.content_encoding['Content-Type'] = (ctype, params)
 
     try:
         out = MIMEPart(ctype, **params)
-    except TypeError:
-        raise EncodingError("Content-Type malformed, not allowed: %r; %r" %
-                            (ctype, params))
+    except TypeError, exc:
+        raise EncodingError("Content-Type malformed, not allowed: %r; %r (Python ERROR: %s" %
+                            (ctype, params, exc.message))
 
     for k in mail.keys():
-        out[k.encode('ascii')] = header_to_mime_encoding(mail[k])
+        if k in ADDRESS_HEADERS_WHITELIST:
+            out[k.encode('ascii')] = header_to_mime_encoding(mail[k])
+        else:
+            out[k.encode('ascii')] = header_to_mime_encoding(mail[k], not_email=True)
 
     out.extract_payload(mail)
 
@@ -268,10 +285,12 @@ def to_message(mail):
     return out
 
 
-def to_string(mail, envelope_header=True):
+def to_string(mail, envelope_header=False):
     """Returns a canonicalized email string you can use to send or store
     somewhere."""
-    return to_message(mail).as_string(envelope_header)
+    msg = to_message(mail).as_string(envelope_header)
+    assert "From nobody" not in msg
+    return msg
 
 
 def from_string(data):
@@ -323,13 +342,23 @@ def decode_message_body(mail, message):
             pass
 
 
+def properly_encode_header(value, encoder, not_email):
+    """
+    The only thing special (weird) about this function is that it tries
+    to do a fast check to see if the header value has an email address in
+    it.  Since random headers could have an email address, and email addresses
+    have weird special formatting rules, we have to check for it.
 
-def header_to_mime_encoding(value):
-    encoder = Charset(DEFAULT_ENCODING)
+    Normally this works fine, but in Librelist, we need to "obfuscate" email
+    addresses by changing the '@' to '-AT-'.  This is where
+    VALUE_IS_EMAIL_ADDRESS exists.  It's a simple lambda returning True/False
+    to check if a header value has an email address.  If you need to make this
+    check different, then change this.
+    """
     try:
         return value.encode("ascii")
     except UnicodeEncodeError:
-        if '@' in value:
+        if not_email is False and VALUE_IS_EMAIL_ADDRESS(value):
             # this could have an email address, make sure we don't screw it up
             name, address = parseaddr(value)
             return '"%s" <%s>' % (encoder.header_encode(name.encode("utf-8")), address)
@@ -337,6 +366,16 @@ def header_to_mime_encoding(value):
         return encoder.header_encode(value.encode("utf-8"))
 
 
+def header_to_mime_encoding(value, not_email=False):
+    if not value: return ""
+
+    encoder = Charset(DEFAULT_ENCODING)
+    if type(value) == list:
+        return "; ".join(properly_encode_header(v, encoder, not_email) for v in value)
+    else:
+        return properly_encode_header(value, encoder, not_email)
+
+
 def header_from_mime_encoding(header):
     if header is None: 
         return header
@@ -441,8 +480,11 @@ def _parse_charset_header(data):
 
             while continued:
                 l, eh, ed, continued = scanner.next()
-
-                if eh[0] == enc_header[0] and eh[1] == enc_header[1]:
+               
+                if not eh:
+                    assert not ed, "Parsing error, give Zed this: %r" % data
+                    oddness = (" " + l.lstrip(), eh, ed, continued)
+                elif eh[0] == enc_header[0] and eh[1] == enc_header[1]:
                     enc_data += ed
                 else:
                     # odd case, it's continued but not from the same base64
